PAWpySeed: pawpyseed.analysis.defect_composition.BasisExpansion Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
pawpyseed.analysis.defect_composition.BasisExpansion Class Reference
Inheritance diagram for pawpyseed.analysis.defect_composition.BasisExpansion:
[legend]
Collaboration diagram for pawpyseed.analysis.defect_composition.BasisExpansion:
[legend]

## Static Public Member Functions
def | makeit (generator)

## Additional Inherited Members
Public Member Functions inherited from pawpyseed.analysis.defect_composition.PawpyData
def | __init__ (self, structure, data, dos=None, vbm=None, cbm=None)
def | set_band_properties (vbm, cbm)
def | as_dict (self)
def | write_yaml (self, filename)
def | from_dict (cls, data)
def | from_yaml (cls, filename)
Public Attributes inherited from pawpyseed.analysis.defect_composition.PawpyData
| energies
| densities
| efermi
| structure
| data
| cbm
| vbm
| bandgap

## Detailed Description

    The data member for the BasisExpansion is 2D array of shape
    (wf.nband, basis.nband * basis.nwk * basis.nspin).
    Each item is the projection of a band of wf onto a band of
    basis for a given k-point index and spin index.

## Member Function Documentation

def pawpyseed.analysis.defect_composition.BasisExpansion.makeit | ( |  | generator | ) |
| static

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/defect_composition.py